@@ -1,59 +1,20 @@
-/*
- * ====================================================================
+/* $Id: NodeCreateRuleTestCase.java 476030 2006-11-17 02:40:25Z rahul $
  *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Commons", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- */
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */ 
 
 
 package org.apache.commons.digester;
@@ -84,7 +45,7 @@ import org.xml.sax.SAXException;
  * <p>Test case for the <code>NodeCreateRule</code>.
  * 
  * @author Christopher Lenz
- * @version $Revision: 1.3 $ $Date: 2003/04/16 11:23:49 $
+ * @version $Revision: 476030 $ $Date: 2006-11-16 21:40:25 -0500 (Thu, 16 Nov 2006) $
  */
 
 public class NodeCreateRuleTestCase extends TestCase {
@@ -168,6 +129,7 @@ public class NodeCreateRuleTestCase extends TestCase {
         try {
             Rule rule = new NodeCreateRule(Node.ATTRIBUTE_NODE);
             fail("IllegalArgumentException expected for type ATTRIBUTE_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
@@ -175,18 +137,21 @@ public class NodeCreateRuleTestCase extends TestCase {
             Rule rule = new NodeCreateRule(Node.CDATA_SECTION_NODE);
             fail("IllegalArgumentException expected for type " +
                  "CDATA_SECTION_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
         try {
             Rule rule = new NodeCreateRule(Node.COMMENT_NODE);
             fail("IllegalArgumentException expected for type COMMENT_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
         try {
             Rule rule = new NodeCreateRule(Node.DOCUMENT_NODE);
             fail("IllegalArgumentException expected for type DOCUMENT_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
@@ -194,12 +159,14 @@ public class NodeCreateRuleTestCase extends TestCase {
             Rule rule = new NodeCreateRule(Node.DOCUMENT_TYPE_NODE);
             fail("IllegalArgumentException expected for type " +
                  "DOCUMENT_TYPE_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
         try {
             Rule rule = new NodeCreateRule(Node.ENTITY_NODE);
             fail("IllegalArgumentException expected for type ENTITY_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
@@ -207,12 +174,14 @@ public class NodeCreateRuleTestCase extends TestCase {
             Rule rule = new NodeCreateRule(Node.ENTITY_REFERENCE_NODE);
             fail("IllegalArgumentException expected for type " +
                  "ENTITY_REFERENCE_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
         try {
             Rule rule = new NodeCreateRule(Node.NOTATION_NODE);
             fail("IllegalArgumentException expected for type NOTATION_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
@@ -220,12 +189,14 @@ public class NodeCreateRuleTestCase extends TestCase {
             Rule rule = new NodeCreateRule(Node.PROCESSING_INSTRUCTION_NODE);
             fail("IllegalArgumentException expected for type " +
                  "PROCESSING_INSTRUCTION_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
         try {
             Rule rule = new NodeCreateRule(Node.TEXT_NODE);
             fail("IllegalArgumentException expected for type TEXT_NODE");
+            assertNotNull(rule); // just to prevent compiler warning on unused var
         } catch (IllegalArgumentException iae) {
             // expected
         }
@@ -421,6 +392,55 @@ public class NodeCreateRuleTestCase extends TestCase {
 
     }
 
+    /**
+     * Tests whether namespaced attributes are handled correctly, using the example from 
+     * the file Test10 XML file.
+     */
+    public void testNamespacedAttribute()
+        throws SAXException, ParserConfigurationException, IOException {
+        
+        digester.setNamespaceAware(true);
+        digester.setRuleNamespaceURI(null);
+        digester.addRule("employee",
+                         new NodeCreateRule(Node.ELEMENT_NODE));
+        Object result = digester.parse(getInputStream("Test10.xml"));
+
+        assertNotNull(result);
+        assertTrue(result instanceof Element);
+        Element element = (Element)result;
+        
+        assertNotNull(element.getAttributeNodeNS("http://jakarta.apache.org/digester/Bar", "test"));
+        assertEquals("MyTestAttribute", element.getAttributeNodeNS("http://jakarta.apache.org/digester/Bar", "test").getNodeValue());
+        assertEquals("test", element.getAttributeNodeNS("http://jakarta.apache.org/digester/Bar", "test").getLocalName());
+        assertEquals("bar", element.getAttributeNodeNS("http://jakarta.apache.org/digester/Bar", "test").getPrefix());
+        assertEquals("bar:test", element.getAttributeNodeNS("http://jakarta.apache.org/digester/Bar", "test").getName());
+
+    }      
+    
+    /**
+     * Tests whether non-namespaced attributes are handled correctly, using the example from 
+     * the file Test11 XML file.
+     */
+    public void testNonNamespacedAttribute()
+        throws SAXException, ParserConfigurationException, IOException {
+        
+        digester.setNamespaceAware(true);
+        digester.setRuleNamespaceURI(null);
+        digester.addRule("employee",
+                         new NodeCreateRule(Node.ELEMENT_NODE));
+        Object result = digester.parse(getInputStream("Test10.xml"));
+
+        assertNotNull(result);
+        assertTrue(result instanceof Element);
+        Element element = (Element)result;
+        
+        assertNotNull(element.getAttributeNode("firstName"));
+        assertEquals("First Name", element.getAttributeNode("firstName").getNodeValue());
+        assertEquals("firstName", element.getAttributeNode("firstName").getLocalName());
+        assertEquals(null, element.getAttributeNode("firstName").getPrefix());
+        assertEquals("firstName", element.getAttributeNode("firstName").getName());
+
+    }     
 
     /**
      * Tests whether the created fragment can be imported into an existing 
@@ -443,7 +463,6 @@ public class NodeCreateRuleTestCase extends TestCase {
 
     }
 
-
     // ------------------------------------------------ Utility Support Methods
 
 
